'''
Advanced Power Device Mode Wraper Dummy
2009-2010(c) Kirill Plyashkevich <ru.spirit@gmail.com>
'''

from advpowcommon.util.execn import *
from wrappers.device_mode.AbstractDeviceMode import AbstractDeviceMode

class DeviceModeDummy(AbstractDeviceMode):

  def pre_init(self):
    self.friendly_name = 'Dummy'
    self.depends['packages'] = {'advanced-power-monitor': '0.5.1'}
    self.interfaces_map = {}
    self.export_signals = {'device_mode': {},
                           'system_inactive': {}
                          }

  def get_status(self):
    pass

  def device_mode_handler(self, *args):
    pass

  def get_device_mode(self):
    return 'unknown'

  def set_device_mode(self, mode):
    pass

  def system_inactive_handler(self):
    pass

  def get_system_inactive(self):
    return False

  def set_system_inactive(self, mode):
    pass

  def tklock(self):
    pass

  def reboot(self):
    run_shell_command_async("reboot")

  def shutdown(self):
    run_shell_command_async("shutdown -h now")
